> TODO: remove prefix "codicem." from these files so the URN:DATA resolving
        become simpler. Note that there is need to fix symbolic links
        (Emerson Rocha, 2021-04-24 20:52 UTC)

> TODO: link ontologia/iso/iso-iec.5218.hxl.csv to ontologia/codicem/sexum/binarium.hxl.csv (Emerson Rocha, 2021-04-28 03:11 UTC)